@@ -104,7 +104,7 @@ impl<'a> Iterator for Tokenizer<'a> {
 
         if let Some(ref t) = t {
             match *t {
-                Ok(Token::ElementStart(_)) => {
+                Ok(Token::ElementStart(_, _)) => {
                     self.state = State::Attributes;
                 }
                 Ok(Token::ElementEnd(ref end)) => {
@@ -112,7 +112,7 @@ impl<'a> Iterator for Tokenizer<'a> {
                         ElementEnd::Open => {
                             self.depth += 1;
                         }
-                        ElementEnd::Close(_) => {
+                        ElementEnd::Close(_, _) => {
                             if self.depth > 0 {
                                 self.depth -= 1;
                             }
@@ -401,14 +401,14 @@ impl<'a> Tokenizer<'a> {
         let encoding = Self::parse_encoding_decl(s)?;
         let standalone = Self::parse_standalone(s)?;
 
-        s.skip_spaces();
+        s.skip_ascii_spaces();
         s.skip_string(b"?>")?;
 
         Ok(Token::Declaration(version, encoding, standalone))
     }
 
     fn parse_version_info(s: &mut Stream<'a>) -> Result<StrSpan<'a>> {
-        s.skip_spaces();
+        s.skip_ascii_spaces();
         s.skip_string(b"version")?;
         s.consume_eq()?;
         s.consume_quote()?;
@@ -429,7 +429,7 @@ impl<'a> Tokenizer<'a> {
 
     // S 'encoding' Eq ('"' EncName '"' | "'" EncName "'" )
     fn parse_encoding_decl(s: &mut Stream<'a>) -> Result<Option<StrSpan<'a>>> {
-        s.skip_spaces();
+        s.skip_ascii_spaces();
 
         if s.skip_string(b"encoding").is_err() {
             return Ok(None);
@@ -476,7 +476,7 @@ impl<'a> Tokenizer<'a> {
 
     // S 'standalone' Eq (("'" ('yes' | 'no') "'") | ('"' ('yes' | 'no') '"'))
     fn parse_standalone(s: &mut Stream<'a>) -> Result<Option<StrSpan<'a>>> {
-        s.skip_spaces();
+        s.skip_ascii_spaces();
 
         if s.skip_string(b"standalone").is_err() {
             return Ok(None);
@@ -742,8 +742,8 @@ impl<'a> Tokenizer<'a> {
 
     // '<' Name (S Attribute)* S? '>'
     fn parse_element_start_impl(s: &mut Stream<'a>) -> Result<Token<'a>> {
-        let tag_name = s.consume_name()?;
-        Ok(Token::ElementStart(tag_name))
+        let (prefix, tag_name) = s.consume_qname()?;
+        Ok(Token::ElementStart(prefix, tag_name))
     }
 
     fn parse_close_element(s: &mut Stream<'a>) -> Result<Token<'a>> {
@@ -756,16 +756,16 @@ impl<'a> Tokenizer<'a> {
 
     // '</' Name S? '>'
     fn parse_close_element_impl(s: &mut Stream<'a>) -> Result<Token<'a>> {
-        let tag_name = s.consume_name()?;
-        s.skip_spaces();
+        let (prefix, tag_name) = s.consume_qname()?;
+        s.skip_ascii_spaces();
         s.consume_byte(b'>')?;
 
-        Ok(Token::ElementEnd(ElementEnd::Close(tag_name)))
+        Ok(Token::ElementEnd(ElementEnd::Close(prefix, tag_name)))
     }
 
     // Name Eq AttValue
     fn consume_attribute(s: &mut Stream<'a>) -> Result<Token<'a>> {
-        s.skip_spaces();
+        s.skip_ascii_spaces();
 
         if let Some(c) = s.get_curr_byte() {
             match c {
@@ -782,7 +782,7 @@ impl<'a> Tokenizer<'a> {
             }
         }
 
-        let name = s.consume_name()?;
+        let (prefix, name) = s.consume_qname()?;
         s.consume_eq()?;
         let quote = s.consume_quote()?;
         let value = s.consume_bytes(|_, c| c != quote);
@@ -793,9 +793,9 @@ impl<'a> Tokenizer<'a> {
         // }
 
         s.consume_byte(quote)?;
-        s.skip_spaces();
+        s.skip_ascii_spaces();
 
-        Ok(Token::Attribute(name, value))
+        Ok(Token::Attribute((prefix, name), value))
     }
 
     fn parse_text(s: &mut Stream<'a>) -> Result<Token<'a>> {
